# Contributing to Snap

:tada: First of all, thank you for considering contributing to Snap! :tada:

Here you will find some guidelines on how to contribute. Feel free to propose changes to this document if you think something is missing or needs to be clarified.

## Code of Conduct

Always try your best to make a positive impact on this project and its community. By participating, you are expected to uphold the [Code of Conduct](CODE_OF_CONDUCT.md). Please report any unacceptable behavior to j.olaleye.o@gmail.com.

## How Can I Contribute?

First time contributing? You can learn more about contributing to open source projects through GitHub's [wonderful open source guides](https://opensource.guide/how-to-contribute/).

### :bug: Reporting a Bug

Before you open a new issue, check to see if the problem has [already been reported](https://github.com/jolaleye/snap/issues). If it has and **the issue is still open**, add a comment to the existing issue instead of creating a new one.

> **Note:** If you find a **closed** issue that seems to address the same thing that you're experiencing, open a new issue and include a link to the original one.

When you open an issue, explain the problem clearly to help maintainers reproduce and fix the problem:

- **Use a clear and descriptive title** for the issue to identify the problem.
- **Give a clear and concise description** of what the problem is.
- **Provide clear steps** to reproduce the issue. Explain both what you did and **how** you did it.
- **Describe what you expected** to happen.
- **Include screenshots or animated GIFs** if necessary that show you following the described steps and clearly show the problem.

You'll also see this information when you open an issue, so don't worry if you forget some of the points.

### :bulb: Requesting a Feature

Snap is a simple and flexible tool used to save and organize boilerplates so that later you can start projects in a snap. :wink: It's meant to be easy to learn and easy to use. Before you request a new feature, consider whether the idea fits the scope of this project. 

If you find yourself wishing for a feature that doesn't exist yet, you're probably not alone. Search through the [issues](https://github.com/jolaleye/snap/issues) to see if someone else wants the same thing and contribute to the conversation. If the idea hasn't been brought up yet, [open an issue](https://github.com/jolaleye/snap/issues/new?template=feature_request.md) that explains the feature you'd like to see, why you need it, and how it should work.

### :sparkles: Opening a Pull Request

A lot of the following information was inspired by [opensource.guide](https://opensource.guide/how-to-contribute/), a great site to learn all about open source software.

If you've fixed a bug, started working on a feature, improved documentation, or done something else, you can [create a pull request](https://github.com/jolaleye/snap/pulls) to start a conversation about your changes.

A pull request doesn't necessarily have to include finished work. It may be better to open a PR early on so that you can get feedback on your contribution. Just mention that it's a work in progress and keep adding commits.

When you make changes, try to adopt the style of the project as best as you can. This includes things like code style and commit messages. Doing so will help your changes integrate smoothly.

Here's how to contribute and submit your pull request:

1. [**Fork the repository**](https://help.github.com/articles/fork-a-repo/) and clone it locally. Add the original repository as a remote and pull in changes every so often so that you stay up to date with the project.
2. [**Create a branch**](https://guides.github.com/introduction/flow/) from `master` for your changes.
3. **Add, commit, and push** your changes to your branch.
4. **Test out your changes.** Make sure you didn't break anything. :smile:
4. [**Open a pull request**](https://github.com/jolaleye/snap/pulls) to merge your branch into `master`.
    - Reference any issues related to your PR (e.g. "Closes #123").
    - Describe your changes in detail and include all of the information in the template.
5. :sunglasses: Sit back, relax, and wait for your PR to be reviewed. You might have to tweak your contribution or elaborate on your changes. That's OK, don't be afraid to justify your reasoning and ask questions.

Thank you for reading through this contributing guide and welcome to the community! :v: :tada: